DefineConstant[
  Flag_AnalysisType = {2, Choices{ 0="Steady-state", 2="Transient"},
    Name "Parameters/0Type of analysis"}
];

Group {
  Domain  = Region[1000] ;
  Surf_Domain = Region[2000] ;
  l_rod   = Region[2001] ;
  r_rod   = Region[2002] ;
}

Function {
  DefineConstant[
    timemax = {100, Min 0.01, Max 20, Step 0.1,
      Name "Parameters/1Simulation time"}
    dtime = {1, Min 0.1, Max 100, Step 0.1,
      Name "Parameters/1Time step"}
    kleft = {209, Min 1, Max 1000, Step 1,
      Name "Parameters/2Temperature (Left Rod)" },
    kright = {394, Main 1, Max 1000, Step 1,
      Name "Parameters/2Temperature (Right Rod)" },
    kinit = {27.3, Main 1, Max 1000, Step 1,
      Name "Parameters/2Temperature (Initial)" },
    kdomain = {273, Main 1, Max 1000, Step 1,
      Name "Parameters/2Temperature (Domain Surface)" },
    rhoc = {8940 * 385, Min 1e3, Max 1e8, Step 1e3,
      Name "Parameters/2rho Cp" } // Cuppper
    kappa = {401, Min 1, Max 1000, Step 1,
      Name "Parameters/2Kappa" } // Cupper
  ];
  k[] = kappa;
  rhoc[] = rhoc ;
  qVol[] = 0; // no heat source.

  t0 = 0;
  t1 = timemax;
  dt = dtime;

}

Constraint {
  { Name Temperature ;
    Case {
      { Region l_rod ; Type Assign; Value kleft ; }
      { Region r_rod ; Type Assign; Value kright ; }
      { Region Surf_Domain ; Type Assign; Value kdomain ; }
      If(Flag_AnalysisType != 0)
        { Region Domain ; Type Init; Value kinit ; }
      EndIf
    }
  }
}

Jacobian {
  { Name JVol ;
    Case {
      { Region All ; Jacobian Vol ; }
    }
  }
  { Name JSur ;
    Case {
      { Region All ; Jacobian Sur ; }
    }
  }
}

Integration {
  { Name I1 ;
    Case {
      { Type Gauss ;
        Case {
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  3 ; }
	  { GeoElement Triangle    ; NumberOfPoints  4 ; }
	  { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
	  { GeoElement Prism       ; NumberOfPoints  6 ; }
	}
      }
    }
  }
}

FunctionSpace {
  { Name Hgrad_T; Type Form0;
    BasisFunction {
      { Name sn; NameOfCoef Tn; Function BF_Node; Support Domain;
        Entity NodesOf[All]; }
    }
    Constraint {
      { NameOfCoef Tn; EntityType NodesOf ; NameOfConstraint Temperature; }
    }
  }

}

Formulation {

  { Name The_T ; Type FemEquation;
    Quantity {
      { Name T;  Type Local; NameOfSpace Hgrad_T; }
    }
    Equation {
      Galerkin { [ k[] * Dof{d T} , {d T} ];
                 In Domain; Integration I1; Jacobian JVol;  }

      Galerkin { DtDof [ rhoc[] * Dof{T} , {T} ];
                 In Domain; Integration I1; Jacobian JVol;  }

      Galerkin { [ -qVol[] , {T} ];
                 In Domain; Integration I1; Jacobian JVol;  }

    }
  }

}

Resolution {
  { Name analysis;
    System {
      { Name T; NameOfFormulation The_T; }
    }
    Operation {
      If(Flag_AnalysisType == 0) // steady state
        Generate[T] ; Solve T ; SaveSolution T;
      EndIf
      If(Flag_AnalysisType == 2) // transient linear fast
        InitSolution[T] ;  SaveSolution[T] ;
        GenerateSeparate[T] ;
	TimeLoopTheta [t0, t1, dt, 1.0] {
	  Update[T] ;
	  SolveAgain[T] ;
	}
      EndIf
    }
  }
}


PostProcessing {
  { Name The; NameOfFormulation The_T;
    Quantity {
      { Name T; Value{ Local{ [ {T} ] ; In Domain; Jacobian JVol; } } }
    }
  }

}


PostOperation {

  { Name T ; NameOfPostProcessing The ;
    Operation {
      Print[ T, OnElementsOf Domain , File "T.pos"];
    }
  }

}

DefineConstant[
  // preset all getdp options and make them invisible
  R_ = {"analysis", Name "GetDP/1ResolutionChoices", Visible 0},
  C_ = {"-solve -pos -v2 -bin", Name "GetDP/9ComputeCommand", Visible 0},
  P_ = {"T", Name "GetDP/2PostOperationChoices", Visible 0}
];
